@@ -5,7 +5,7 @@ from ..common.object_wrapper import FunctionWrapper, wrap_object
 
 class ErrorTrace(object):
 
-    def __init__(self, transaction, ignore_errors=None):
+    def __init__(self, transaction, ignore_errors=[]):
         self._transaction = transaction
         self._ignore_errors = ignore_errors
 
@@ -22,7 +22,7 @@ class ErrorTrace(object):
         self._transaction.record_exception(exc=exc, value=value, tb=tb,
                 ignore_errors=self._ignore_errors)
 
-def ErrorTraceWrapper(wrapped, ignore_errors=None):
+def ErrorTraceWrapper(wrapped, ignore_errors=[]):
 
     def wrapper(wrapped, instance, args, kwargs):
         transaction = current_transaction()
@@ -35,8 +35,8 @@ def ErrorTraceWrapper(wrapped, ignore_errors=None):
 
     return FunctionWrapper(wrapped, wrapper)
 
-def error_trace(ignore_errors=None):
+def error_trace(ignore_errors=[]):
     return functools.partial(ErrorTraceWrapper, ignore_errors=ignore_errors)
 
-def wrap_error_trace(module, object_path, ignore_errors=None):
+def wrap_error_trace(module, object_path, ignore_errors=[]):
     wrap_object(module, object_path, ErrorTraceWrapper, (ignore_errors, ))
